@@ -16,11 +16,14 @@ NAME = 'quit_server'
 
 def get_argparse(parent_parser=None):
     if parent_parser is None:
-        parser = argparse.ArgumentParser(description='Quit the server')
+        p = argparse.ArgumentParser(description='Quit the server')
     else:
-        parser = parent_parser.add_parser(NAME, help='Quit the server')
+        p = parent_parser.add_parser(NAME, help='Quit the server')
 
-    return parser
+    p.add_argument('--host', type=str, default='127.0.0.1')
+    p.add_argument('--port', type=int, default=8000)
+
+    return p
 
 
 def main(host='127.0.0.1', port=8000, **kwargs):
@@ -29,8 +32,6 @@ def main(host='127.0.0.1', port=8000, **kwargs):
 
 if __name__ == '__main__':
     P = get_argparse()
-    P.add_argument('--host', type=str, default='127.0.0.1')
-    P.add_argument('--port', type=int, default=8000)
     ARGS = P.parse_args()
 
     KWARGS = {n: getattr(ARGS, n) for n in dir(ARGS) if not n.startswith('_') and getattr(ARGS, n, None) is not None}
