@@ -16,13 +16,16 @@ NAME = 'run'
 
 def get_argparse(list_schedules=True, parent_parser=None):
     if parent_parser is None:
-        parser = argparse.ArgumentParser(description='Update the server command modules.')
+        p = argparse.ArgumentParser(description='Update the server command modules.')
     else:
-        parser = parent_parser.add_parser(NAME, help='Update the server command modules.')
+        p = parent_parser.add_parser(NAME, help='Update the server command modules.')
 
-    parser.add_argument('--update_path', type=str, help='Command path that "update" imports files from.')
+    p.add_argument('--update_path', type=str, help='Command path that "update" imports files from.')
 
-    return parser
+    p.add_argument('--host', type=str, default='127.0.0.1')
+    p.add_argument('--port', type=int, default=8000)
+
+    return p
 
 
 def main(update_path: str = None, host='127.0.0.1', port=8000, **kwargs):
@@ -35,8 +38,6 @@ def main(update_path: str = None, host='127.0.0.1', port=8000, **kwargs):
 
 if __name__ == '__main__':
     P = get_argparse()
-    P.add_argument('--host', type=str, default='127.0.0.1')
-    P.add_argument('--port', type=int, default=8000)
     ARGS = P.parse_args()
 
     KWARGS = {n: getattr(ARGS, n) for n in dir(ARGS) if not n.startswith('_') and getattr(ARGS, n, None) is not None}
